@@ -40,7 +40,7 @@
 #'
 #' **Criterion**
 #'
-#' If no criterion is specified, ten the criterion specified for the method in
+#' If no criterion is specified, then the criterion specified for the method in
 #' the registry (see `[get_seriation_method()]`) is used. For methods with no
 #' criterion in the registry (marked as "other"), a default method is used.
 #' The defaults are:
@@ -92,7 +92,7 @@
 #' d_supreme <- as.dist(SupremeCourt)
 #'
 #' # find best seriation order (tries by by default several fast methods)
-#' o <- seriate_best(d_supreme, criterion = "AR_events")
+#' o <- seriate_best(d_supreme, criterion = "AR_events", rep = 5)
 #' o
 #' pimage(d_supreme, o)
 #'
@@ -175,7 +175,7 @@ seriate_best <- function(x,
     FUN = function(m) {
       if (verbose) {
         cat("\n")
-        cat(m, " - ")
+        cat(m, "- ")
       }
       #tm <- system.time(o <- seriate(x, m, ...))
       tm <-
@@ -240,7 +240,6 @@ seriate_rep <- function(x,
   if (is.na(criterion))
     criterion <- get_default_criterion(x)
 
-
   if (!m$randomized && rep > 1L) {
     rep <- 1L
     if (verbose)
@@ -248,7 +247,7 @@ seriate_rep <- function(x,
   }
 
   if (verbose && rep > 1L) {
-    cat("Tries", rep, " ")
+    cat("Replications", rep, " ")
   }
 
   #r <- replicate(rep, { if (verbose) cat("."); seriate(x, method, control) },
